#!/bin/bash
set -e

LOCK_EBITENGINE=v2.8.8

export PROJECTPATH=$PWD
export GOPATH="$PROJECTPATH/go"

if [ -z "$1" ]; then
	echo "Usage: ./bind.sh <boxcars tag, commit hash or local path>"
	exit 1
fi

echo "Installing ebitenmobile..."
go install github.com/hajimehoshi/ebiten/v2/cmd/ebitenmobile@$LOCK_EBITENGINE

BOXCARSPATH=""
if [[ "$1" == *\/* ]]; then
	BOXCARSPATH=$1/game/mobile
else
	echo "Downloading boxcars $1..."
	mkdir -p $GOPATH/src/codeberg.org/tslocum
	if [ ! -d "$GOPATH/src/codeberg.org/tslocum/boxcars" ]; then
		git clone https://codeberg.org/tslocum/boxcars $GOPATH/src/codeberg.org/tslocum/boxcars
	fi
	cd $GOPATH/src/codeberg.org/tslocum/boxcars && git fetch origin && git reset --hard `printf %q "$1"` && cd $PROJECTPATH
	BOXCARSPATH=$GOPATH/src/codeberg.org/tslocum/boxcars/game/mobile
fi

echo "Binding boxcars..."
mkdir -p libs
PATH="$PROJECTPATH/go/bin:$PATH"
cd $BOXCARSPATH
# Issue: https://github.com/golang-design/clipboard/pull/82
go mod edit -replace=golang.design/x/clipboard=github.com/tslocum/clipboard@shiny
go mod tidy
ebitenmobile bind -target android -androidapi 21 -javapkg com.rocket9labs.boxcars -o $PROJECTPATH/libs/boxcars.aar .

echo "Finished."
